﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views;
using Arction.WinForms.Charting.Views.ViewXY;

namespace TestMemoryLeak
{
    public partial class Form1 : Form
    {
        LightningChartUltimate chart;
        public Form1()
        {
            InitializeComponent();
            this.InitDemo();
            this.timer1.Start();
        }


        private void InitDemo()
        {
            chart = new LightningChartUltimate();
            chart.BeginUpdate();
            chart.Resize += Chart_Resize;

            chart.ViewXY.AxisLayout.AutoAdjustMargins = false;
            chart.ViewXY.AxisLayout.YAxesLayout = YAxesLayout.Layered;
            chart.Title.Visible = false;

            chart.ViewXY.XAxes[0].SetRange(0, 100);
            chart.ViewXY.XAxes[0].ValueType = AxisValueType.Number;
            chart.ViewXY.DropOldSeriesData = true;

            chart.ViewXY.YAxes.Clear();

            for (int i = 0; i < 5; i++)
            {
                AddSeriesAndYAxis("Series" + (i + 1).ToString());
            }
            chart.ViewXY.LegendBox.Visible = true;
            chart.ViewXY.LegendBox.Offset = new PointIntXY(0, 0);
            chart.ViewXY.LegendBox.AutoSize = true;
            chart.ViewXY.LegendBox.Shadow.Visible = false;
            chart.ViewXY.LegendBox.BorderWidth = 1;
            chart.ViewXY.LegendBox.ScrollBarVisibility = LegendBoxBase.LegendBoxScrollBarVisibility.None;
            chart.ViewXY.LegendBox.Position = LegendBoxPosition.TopCenter;
            chart.ViewXY.LegendBox.MouseInteraction = true;
            chart.ViewXY.LegendBox.ShowCheckboxes = true;
            chart.ViewXY.LegendBox.MoveByMouse = false;
            chart.ViewXY.LegendBox.MouseHighlight = MouseOverHighlight.None;
            chart.ViewXY.LegendBox.Layout = LegendBoxLayout.HorizontalRowSpan;
            chart.ViewXY.LegendBox.MoveFromSeriesTitle = false;


            chart.ColorTheme = ColorTheme.Dark;

            chart.EndUpdate();
            Chart_Resize(this, EventArgs.Empty);
            
            chart.Dock = DockStyle.Fill;
            this.Controls.Add(chart);
        }

        private void Chart_Resize(object sender, EventArgs e)
        {
            chart.BeginUpdate();
            chart.TweakDisablePresent();
            chart.ViewXY.AxisLayout.AutoAdjustMargins = true;
            chart.EndUpdate();

            Rectangle r = chart.ViewXY.GetMarginsRect();

            chart.BeginUpdate();
            chart.ViewXY.AxisLayout.AutoAdjustMargins = false;

            var ra = chart.ViewXY.LegendBox.GetRenderedRect();
            chart.ViewXY.Margins = new Padding(r.Left, ra.Y + ra.Height + 10,
                chart.ClientSize.Width - r.Right,
                chart.ClientSize.Height - r.Bottom);

            chart.TweakEnablePresent();
            chart.EndUpdate();
        }

        private void AddSeriesAndYAxis(string name)
        {
            this.chart.BeginUpdate();

            AxisY axisY = new AxisY(chart.ViewXY);
            axisY.Title.Visible = false;
            axisY.SetRange(0, 100000);
            chart.ViewXY.YAxes.Add(axisY);

            var series = new PointLineSeries(chart.ViewXY, chart.ViewXY.XAxes[0], axisY);
            series.MouseInteraction = false;
            series.Title.Text = name;
            chart.ViewXY.PointLineSeries.Add(series);
            int index = chart.ViewXY.PointLineSeries.IndexOf(series);
            series.LineStyle.Color = DefaultColors.Series[(index) % DefaultColors.Series.Length];

            this.chart.EndUpdate();
        }

        Random rand = new Random();
        int x = 0;
        private void timer1_Tick(object sender, EventArgs e)
        {
            this.chart.BeginUpdate();
            for (int k = 0; k < 1000; k++)
            {
                int count = this.chart.ViewXY.PointLineSeries.Count;
                for (int i = 0; i < count; i++)
                {
                    this.chart.ViewXY.PointLineSeries[i].AddPoints(new SeriesPoint[] { new SeriesPoint(x, rand.Next(0, 100000)) }, false);
                }
                x++;
                chart.ViewXY.XAxes[0].ScrollPosition = x; 
            }
            this.chart.EndUpdate();
        }
    }

}
